Struct sea_streamer::export::time::Instant
#[repr(transparent)]pub struct Instant(pub Instant);Expand description
A measurement of a monotonically non-decreasing clock. Opaque and useful only with Duration.
Instants are always guaranteed to be no less than any previously measured instant when created, and are often useful for tasks such as measuring benchmarks or timing how long an operation takes.
Note, however, that instants are not guaranteed to be steady. In other words, each tick of the underlying clock may not be the same length (e.g. some seconds may be longer than others). An instant may jump forwards or experience time dilation (slow down or speed up), but it will never go backwards.
Instants are opaque types that can only be compared to one another. There is no method to get โthe number of secondsโ from an instant. Instead, it only allows measuring the duration between two instants (or comparing two instants).
This implementation allows for operations with signed Durations, but is otherwise identical
to std::time::Instant.
Tuple Fields
0: InstantImplementations
impl Instant
impl Instant
pub fn now() -> Instant
pub fn now() -> Instant
Returns an Instant corresponding to โnowโ.
println!("{:?}", Instant::now());pub fn elapsed(self) -> Duration
pub fn elapsed(self) -> Duration
Returns the amount of time elapsed since this instant was created. The duration will always be nonnegative if the instant is not synthetically created.
let instant = Instant::now();
thread::sleep(1.std_milliseconds());
assert!(instant.elapsed() >= 1.milliseconds());pub fn checked_add(self, duration: Duration) -> Option<Instant>
pub fn checked_add(self, duration: Duration) -> Option<Instant>
Returns Some(t) where t is the time self + duration if t can be represented as
Instant (which means itโs inside the bounds of the underlying data structure), None
otherwise.
let now = Instant::now();
assert_eq!(now.checked_add(5.seconds()), Some(now + 5.seconds()));
assert_eq!(now.checked_add((-5).seconds()), Some(now + (-5).seconds()));pub fn checked_sub(self, duration: Duration) -> Option<Instant>
pub fn checked_sub(self, duration: Duration) -> Option<Instant>
Returns Some(t) where t is the time self - duration if t can be represented as
Instant (which means itโs inside the bounds of the underlying data structure), None
otherwise.
let now = Instant::now();
assert_eq!(now.checked_sub(5.seconds()), Some(now - 5.seconds()));
assert_eq!(now.checked_sub((-5).seconds()), Some(now - (-5).seconds()));pub const fn into_inner(self) -> Instant
pub const fn into_inner(self) -> Instant
Obtain the inner std::time::Instant.
let now = Instant::now();
assert_eq!(now.into_inner(), now.0);Trait Implementations
impl AddAssign<Duration> for Instant
impl AddAssign<Duration> for Instant
fn add_assign(&mut self, rhs: Duration)
fn add_assign(&mut self, rhs: Duration)
+= operation. Read moreimpl AddAssign<Duration> for Instant
impl AddAssign<Duration> for Instant
fn add_assign(&mut self, rhs: Duration)
fn add_assign(&mut self, rhs: Duration)
+= operation. Read moreimpl Ord for Instant
impl Ord for Instant
impl PartialEq<Instant> for Instant
impl PartialEq<Instant> for Instant
impl PartialOrd<Instant> for Instant
impl PartialOrd<Instant> for Instant
fn partial_cmp(&self, other: &Instant) -> Option<Ordering>
fn partial_cmp(&self, other: &Instant) -> Option<Ordering>
1.0.0 ยท sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
self and other) and is used by the <=
operator. Read moreimpl PartialOrd<Instant> for Instant
impl PartialOrd<Instant> for Instant
fn partial_cmp(&self, rhs: &Instant) -> Option<Ordering>
fn partial_cmp(&self, rhs: &Instant) -> Option<Ordering>
1.0.0 ยท sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
self and other) and is used by the <=
operator. Read moreimpl SubAssign<Duration> for Instant
impl SubAssign<Duration> for Instant
fn sub_assign(&mut self, rhs: Duration)
fn sub_assign(&mut self, rhs: Duration)
-= operation. Read moreimpl SubAssign<Duration> for Instant
impl SubAssign<Duration> for Instant
fn sub_assign(&mut self, rhs: Duration)
fn sub_assign(&mut self, rhs: Duration)
-= operation. Read more