Type Alias sea_streamer::StreamResult
source · pub type StreamResult<T, E> = Result<T, StreamErr<E>>;Expand description
Type alias of the Result type specific to sea-streamer.
pub type StreamResult<T, E> = Result<T, StreamErr<E>>;Type alias of the Result type specific to sea-streamer.