pub struct SharedMessage { /* private fields */ }Expand description
It uses an Arc to hold the bytes, so is cheap to clone.
Implementations
pub fn new( header: MessageHeader, bytes: Vec<u8>, offset: usize, length: usize, ) -> SharedMessage
pub fn header(&self) -> &MessageHeader
pub fn take_header(self) -> MessageHeader
Sourcepub fn to_owned_message(self) -> OwnedMessage
pub fn to_owned_message(self) -> OwnedMessage
This will attempt to convert self into an OwnedMessage without copying, if the bytes are not shared with any other.